@@ -153,7 +153,7 @@ class Base_Page(Borg, unittest.TestCase):
             self.test_run_id = None
             self.start_time = None  # pytest have Unresolved attribute reference if not added
             self.test_env = ""  # pytest have Unresolved attribute reference if not added
-            self.non_breakable = ""
+            self.breakable = ""
             self.reset()
         self.base_url = base_url
         self.driver_obj = DriverFactory()
@@ -302,15 +302,15 @@ class Base_Page(Borg, unittest.TestCase):
             self.exceptions.append("Error when setting up the screenshot directory")
 
     def assert_true(self, condition, success_message=None, error_message=None, level='info'):
-        self.conditional_write(condition, success_message, error_message, level)
+        self.conditional_write(condition, positive=success_message, negative=error_message, level=level)
 
-        if self.non_breakable == 'N':
+        if self.breakable == 'Y':
             assert_that(condition, equal_to(True), error_message)
 
     def assert_false(self, condition, success_message=None, error_message=None, level='inverse'):
-        self.conditional_write(condition, success_message, error_message, level)
+        self.conditional_write(condition, negative=success_message, positive=error_message, level=level)
 
-        if self.non_breakable == 'N':
+        if self.breakable == 'Y':
             assert_that(condition, equal_to(False), error_message)
 
     def get_screenshot_dir(self, os_name, os_version, browser, browser_version, overwrite_flag=False):
