@@ -74,7 +74,7 @@ class Wrapit():
                     test_obj.save_screenshot(screenshot_name)
 
                 # Detail print in last line
-                with open(test_obj.logs_parent_dir + test_obj.log_name, "a") as logfile:
+                with open(test_obj.logs_parent_dir + "\\" + test_obj.log_name, "a") as logfile:
                     traceback.print_exc(file=logfile)
                 globals()['gif_file'] = test_obj.write_test_summary()
                 raise
@@ -92,9 +92,13 @@ class Wrapit():
                 print("Exception when trying to run test: %s" % __file__)
                 print("Python says:%s" % str(e))
                 test_obj.write(traceback.format_exc())
+                if test_obj.screenshot != 'off':        # Add for handling fail screenshot *Break case (Take screenshot for non off case)
+                    screenshot_name = '%003d' % test_obj.screenshot_counter + '_' + func.__name__
+                    test_obj.screenshot_counter += 1
+                    test_obj.save_screenshot(screenshot_name)
 
                 # Detail print in last line
-                with open(test_obj.logs_parent_dir + test_obj.log_name, "a") as logfile:
+                with open(test_obj.logs_parent_dir + "\\" + test_obj.log_name, "a") as logfile:
                     traceback.print_exc(file=logfile)
                 globals()['gif_file'] = test_obj.write_test_summary()
                 raise
@@ -102,7 +106,6 @@ class Wrapit():
 
         return wrapper
 
-
     def _mobile_logging_decorator(func):
 
         def wrapper(test_mobile_obj, product, cases, extra, testID, *args, **kwargs):
@@ -113,9 +116,13 @@ class Wrapit():
                 print("Exception when trying to run test: %s" % __file__)
                 print("Python says:%s" % str(e))
                 test_mobile_obj.write(traceback.format_exc())
+                if test_mobile_obj.screenshot != 'off':        # Add for handling fail screenshot *Break case (Take screenshot for non off case)
+                    screenshot_name = '%003d' % test_mobile_obj.screenshot_counter + '_' + func.__name__
+                    test_mobile_obj.screenshot_counter += 1
+                    test_mobile_obj.save_screenshot(screenshot_name)
 
                 # Detail print in last line
-                with open(test_mobile_obj.logs_parent_dir + test_mobile_obj.log_name, "a") as logfile:
+                with open(test_mobile_obj.logs_parent_dir + "\\" + test_mobile_obj.log_name, "a") as logfile:
                     traceback.print_exc(file=logfile)
                 globals()['gif_file'] = test_mobile_obj.write_test_summary()
                 raise
